@@ -12,7 +12,8 @@ c.method = "complete", d.method = "euclidean", use.sym = FALSE, ...) {
 	if (use.sym) spectra$names <- paste(spectra$alt.sym, spectra$names, sep = " ")
 	distance <- rowDist(as.data.frame(spectra$data, row.names = spectra$names), method = d.method)
 
-	title <- paste(title, ": HCA Analysis", sep = "")
+#	title <- paste(title, ": HCA Analysis", sep = "")
+	title <- bquote(bold(.(eval(title)):~HCA~Analysis))
 	sub.title <- paste("clustering method: ", c.method, "      distance method: ", d.method, sep = "")
 
 	plotHCA(spectra = spectra, distance = distance, title = title, sub.title = sub.title,
