@@ -1,6 +1,6 @@
 
 plotSpectra <- function(spectra, title = "no title provided", which = c(1),
-	yrange = c(0, max(spectra$data)),
+	yrange = range(spectra$data),
 	offset = 0.0, amplify = 1.0,
 	lab.pos = mean(spectra$freq), ...) {
 	
@@ -18,7 +18,7 @@ plotSpectra <- function(spectra, title = "no title provided", which = c(1),
 	plot(spectra$freq, spectrum, type = "l",
 	main = title, xlab = spectra$unit[1], ylab = spectra$unit[2],
 	ylim = yrange, col = spectra$colors[which[1]],
-	frame.plot = FALSE, yaxt = "n", ...)
+	frame.plot = FALSE, ...)
 	grid(ny = NA, lty = 1)
 	lab.x <- lab.pos
 	spec.index <- findInterval(lab.x, sort(spectra$freq))
